==> pysmssend-1.45.tar.gz: pysmssendmod/sites.py <==
# -*- coding: utf-8 -*-
acc_openlogin = {
	'otenet':'http://tools.otenet.gr/tools/index.do',
	'voipbuster':'https://www.voipbuster.com/myaccount/index.php',
	'voipdiscount':'https://www.voipdiscount.com/myaccount/index.php',
	'lowratevoip':'https://www.lowratevoip.com/myaccount/index.php',	
	'voipbusterpro':'https://www.voipbusterpro.com/myaccount/index.php',
	'freevoip':'https://www.freevoip.com/myaccount/index.php',
	'12voip':'https://www.12voip.com/myaccount/index.php',	
	'webcalldirect':'https://www.webcalldirect.com/myaccount/index.php',
	'nonoh':'https://www.nonoh.net/myaccount/index.php',
	'voipcheap':'https://www.voipcheap.com/myaccount/index.php',
	'voipraider':'https://www.voipraider.com/myaccount/index.php',
	'justvoip':'https://www.justvoip.com/myaccount/index.php',
	'forthnet':'https://www.forthnet.gr/secure/webSMS/login.aspx?'
	}	
acc_opensms = {
	'otenet':'http://tools.otenet.gr/tools/tiles/web2sms.do?showPage=smsSend&mnu=smenu23',
	'voipbuster':'https://www.voipbuster.com/myaccount/index.php?part=menu&justloggedin=true',
	'voipdiscount':'https://www.voipdiscount.com/myaccount/index.php?part=menu&justloggedin=true',
	'lowratevoip':'https://www.lowratevoip.com/myaccount/index.php?part=menu&justloggedin=true',
	'voipbusterpro':'https://www.voipbusterpro.com/myaccount/index.php?part=menu&justloggedin=true',
	'freevoip':'https://www.freevoip.com/myaccount/index.php?part=menu&justloggedin=true',
	'12voip':'https://www.12voip.com/myaccount/index.php?part=menu&justloggedin=true',
	'webcalldirect':'https://www.webcalldirect.com/myaccount/index.php?part=menu&justloggedin=true',
	'voipcheap':'https://www.voipcheap.com/myaccount/index.php?part=menu&justloggedin=true',
	'nonoh':'https://www.nonoh.net/myaccount/index.php?part=menu&justloggedin=true',
	'justvoip':'https://www.justvoip.com/myaccount/index.php?part=menu&justloggedin=true',
	'voipraider':'https://www.voipraider.com/myaccount/index.php?part=menu&justloggedin=true',
	'forthnet':'https://www.forthnet.gr/secure/webSMS/default.aspx'
      }

acc_verify = {
        'otenet':'http://tools.otenet.gr/tools/tiles/web2sms.do?showPage=smsSend&mnu=smenu23',
	'voipbuster':'https://myaccount.voipbuster.com/clx/index.php?part=menu&justloggedin=true',
	'voipdiscount':'https://myaccount.voipdiscount.com/clx/index.php?part=menu&justloggedin=true',
	'lowratevoip':'https://myaccount.lowratevoip.com/clx/index.php?part=menu&justloggedin=true',
	'voipbusterpro':'https://myaccount.voipbusterpro.com/clx/index.php?part=menu&justloggedin=true',
	'freevoip':'https://myaccount.freevoip.com/clx/index.php?part=menu&justloggedin=true',
	'12voip':'https://myaccount.12voip.com/clx/index.php?part=menu&justloggedin=true',
	'webcalldirect':'https://www.webcalldirect.com/myaccount/index.php?part=menu&justloggedin=true',
	'voipcheap':'https://www.voipcheap.com/myaccount/index.php?part=menu&justloggedin=true',
	'nonoh':'https://myaccount.nonoh.net/clx/index.php?part=menu&justloggedin=true',
	'voipraider':'https://myaccount.voipraider.net/clx/index.php?part=menu&justloggedin=true',
	'justvoip':'https://myaccount.justvoip.com/clx/index.php?part=menu&justloggedin=true'
}

acc_opensms2 = {
'otenet':'http://tools.otenet.gr/tools/tiles/web2sms.do?showPage=smsSend&mnu=smenu23',
'voipbuster':'https://www.voipbuster.com/myaccount/sendsms.php?username=',
'voipdiscount':'https://www.voipdiscount.com/myaccount/sendsms.php?username=',
'lowratevoip':'https://www.lowratevoip.com/myaccount/sendsms.php?username=',
'voipbusterpro':'https://www.voipbusterpro.com/myaccount/sendsms.php?username=',
'freevoip':'https://www.freevoip.com/myaccount/sendsms.php?username=',
'12voip':'https://www.12voip.com/myaccount/sendsms.php?username=',
'webcalldirect':'https://www.webcalldirect.com/myaccount/sendsms.php?username=',
'nonoh':'https://www.nonoh.com/myaccount/sendsms.php?username=',
'justvoip':'https://www.justvoip.com/myaccount/sendsms.php?username',
'voipcheap':'https://www.voipcheap.com/myaccount/sendsms.php?username',
'voipraider':'https://www.voipraider.com/myaccount/sendsms.php?username'

}

==> pysmssend-1.48.tar.gz: pysmssendmod/sites.py <==
# -*- coding: utf-8 -*-
acc_openlogin = {
	'otenet':'http://tools.otenet.gr/tools/index.do',
	'voipbuster':'https://www.voipbuster.com/en/login',
	'voipdiscount':'https://www.voipdiscount.com/myaccount/index.php',
	'lowratevoip':'https://www.lowratevoip.com/myaccount/index.php',	
	'voipbusterpro':'https://www.voipbusterpro.com/myaccount/index.php',
	'freevoip':'https://www.freevoip.com/myaccount/index.php',
	'12voip':'https://www.12voip.com/myaccount/index.php',	
	'webcalldirect':'https://www.webcalldirect.com/myaccount/index.php',
	'nonoh':'https://www.nonoh.net/myaccount/index.php',
	'voipcheap':'https://www.voipcheap.com/myaccount/index.php',
	'voipraider':'https://www.voipraider.com/myaccount/index.php',
	'justvoip':'https://www.justvoip.com/myaccount/index.php',
	'forthnet':'https://www.forthnet.gr/secure/webSMS/login.aspx?'
	}	
acc_opensms = {
	'otenet':'http://tools.otenet.gr/tools/tiles/web2sms.do?showPage=smsSend&mnu=smenu23',
	'voipbuster':'https://www.voipbuster.com/en/web_sms',
	'voipdiscount':'https://www.voipdiscount.com/myaccount/index.php?part=menu&justloggedin=true',
	'lowratevoip':'https://www.lowratevoip.com/myaccount/index.php?part=menu&justloggedin=true',
	'voipbusterpro':'https://www.voipbusterpro.com/myaccount/index.php?part=menu&justloggedin=true',
	'freevoip':'https://www.freevoip.com/myaccount/index.php?part=menu&justloggedin=true',
	'12voip':'https://www.12voip.com/myaccount/index.php?part=menu&justloggedin=true',
	'webcalldirect':'https://www.webcalldirect.com/myaccount/index.php?part=menu&justloggedin=true',
	'voipcheap':'https://www.voipcheap.com/myaccount/index.php?part=menu&justloggedin=true',
	'nonoh':'https://www.nonoh.net/myaccount/index.php?part=menu&justloggedin=true',
	'justvoip':'https://www.justvoip.com/myaccount/index.php?part=menu&justloggedin=true',
	'voipraider':'https://www.voipraider.com/myaccount/index.php?part=menu&justloggedin=true',
	'forthnet':'https://www.forthnet.gr/secure/webSMS/default.aspx'
      }

acc_verify = {
        'otenet':'http://tools.otenet.gr/tools/tiles/web2sms.do?showPage=smsSend&mnu=smenu23',
	'voipbuster':'https://myaccount.voipbuster.com/clx/index.php?part=menu&justloggedin=true',
	'voipdiscount':'https://myaccount.voipdiscount.com/clx/index.php?part=menu&justloggedin=true',
	'lowratevoip':'https://myaccount.lowratevoip.com/clx/index.php?part=menu&justloggedin=true',
	'voipbusterpro':'https://myaccount.voipbusterpro.com/clx/index.php?part=menu&justloggedin=true',
	'freevoip':'https://myaccount.freevoip.com/clx/index.php?part=menu&justloggedin=true',
	'12voip':'https://myaccount.12voip.com/clx/index.php?part=menu&justloggedin=true',
	'webcalldirect':'https://www.webcalldirect.com/myaccount/index.php?part=menu&justloggedin=true',
	'voipcheap':'https://www.voipcheap.com/myaccount/index.php?part=menu&justloggedin=true',
	'nonoh':'https://myaccount.nonoh.net/clx/index.php?part=menu&justloggedin=true',
	'voipraider':'https://myaccount.voipraider.net/clx/index.php?part=menu&justloggedin=true',
	'justvoip':'https://myaccount.justvoip.com/clx/index.php?part=menu&justloggedin=true'
}

acc_opensms2 = {
	'otenet':'http://tools.otenet.gr/tools/tiles/web2sms.do?showPage=smsSend&mnu=smenu23',
	'voipbuster':'https://www.voipbuster.com/myaccount/sendsms.php?',
	'voipdiscount':'https://www.voipdiscount.com/myaccount/sendsms.php?',
	'lowratevoip':'https://www.lowratevoip.com/myaccount/sendsms.php?',
	'voipbusterpro':'https://www.voipbusterpro.com/myaccount/sendsms.php?',
	'freevoip':'https://www.freevoip.com/myaccount/sendsms.php?',
	'12voip':'https://www.12voip.com/myaccount/sendsms.php?',
	'webcalldirect':'https://www.webcalldirect.com/myaccount/sendsms.php?',
	'nonoh':'https://www.nonoh.com/myaccount/sendsms.php?',
	'justvoip':'https://www.justvoip.com/myaccount/sendsms.php?',
	'voipcheap':'https://www.voipcheap.com/myaccount/sendsms.php?',
	'voipraider':'https://www.voipraider.com/myaccount/sendsms.php?'

}
